@@ -378,7 +378,7 @@ haze_connection_request_avatar (TpSvcConnectionInterfaceAvatars *self,
     else
     {
         DEBUG ("handle %u has no avatar", contact);
-        g_set_error (&error, TP_ERRORS, TP_ERROR_NOT_AVAILABLE,
+        g_set_error (&error, TP_ERROR, TP_ERROR_NOT_AVAILABLE,
                      "handle %u has no avatar", contact);
 
 
@@ -455,7 +455,7 @@ haze_connection_set_avatar (TpSvcConnectionInterfaceAvatars *self,
 
     if (max_filesize > 0 && icon_len > max_filesize)
     {
-        g_set_error (&error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+        g_set_error (&error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
                      "avatar is %" G_GSIZE_FORMAT "B, "
                      "but the limit is %" G_GSIZE_FORMAT "B",
                      icon_len, max_filesize);
@@ -484,7 +484,7 @@ haze_connection_set_avatar (TpSvcConnectionInterfaceAvatars *self,
 
     if (!acceptable_mime_type)
     {
-        g_set_error (&error, TP_ERRORS, TP_ERROR_INVALID_ARGUMENT,
+        g_set_error (&error, TP_ERROR, TP_ERROR_INVALID_ARGUMENT,
             "'%s' is not a supported MIME type", mime_type);
 
         dbus_g_method_return_error (context, error);
@@ -547,7 +547,6 @@ buddy_icon_changed_cb (PurpleBuddy *buddy,
 
     tp_svc_connection_interface_avatars_emit_avatar_updated (conn, contact,
         token);
-    tp_handle_unref (contact_repo, contact);
     g_free (token);
 }
 
