@@ -62,6 +62,8 @@ struct _HazeConnection {
 
     gchar **acceptable_avatar_mime_types;
 
+    GHashTable *client_caps;
+
     /* Part of the hack for Jabber media caps */
     gulong status_changed_id;
 
@@ -109,6 +111,10 @@ const gchar *haze_get_fallback_group (void);
 const gchar **haze_connection_get_implemented_interfaces (void);
 const gchar **haze_connection_get_guaranteed_interfaces (void);
 
+void haze_connection_request_password (PurpleAccount *account,
+                                       gpointer user_data);
+void haze_connection_cancel_password_request (PurpleAccount *account);
+
 G_END_DECLS
 
 #endif /* #ifndef __HAZE_CONNECTION_H__*/
