@@ -193,10 +193,7 @@ haze_contact_list_dup_contacts (TpBaseContactList *cl)
           purple_buddy_get_name (sl_iter->data), NULL, NULL);
 
       if (G_LIKELY (handle != 0))
-        {
-          tp_handle_set_add (handles, handle);
-          tp_handle_unref (contact_repo, handle);
-        }
+        tp_handle_set_add (handles, handle);
     }
 
   g_slist_free (buddies);
@@ -311,8 +308,6 @@ buddy_added_cb (PurpleBuddy *buddy, gpointer unused)
     group_name = purple_group_get_name (purple_buddy_get_group (buddy));
     tp_base_contact_list_one_contact_groups_changed (
         (TpBaseContactList *) contact_list, handle, &group_name, 1, NULL, 0);
-
-    tp_handle_unref (contact_repo, handle);
 }
 
 static void
@@ -362,8 +357,6 @@ buddy_removed_cb (PurpleBuddy *buddy, gpointer unused)
         tp_base_contact_list_one_contact_removed (
             (TpBaseContactList *) contact_list, handle);
     }
-
-    tp_handle_unref (contact_repo, handle);
 }
 
 
@@ -374,7 +367,7 @@ typedef struct _HandleContext {
     TpHandleRepoIface *contact_repo;
     TpHandleSet *add_handles;
 
-    /* Map from group names (const char *) to (TpIntSet *)s of handles */
+    /* Map from group names (const char *) to (TpIntset *)s of handles */
     GHashTable *group_handles;
 } HandleContext;
 
@@ -385,18 +378,11 @@ static void
 remove_pending_publish_request (HazeContactList *self,
                                 TpHandle handle)
 {
-    HazeConnection *conn = self->priv->conn;
-    TpBaseConnection *base_conn = TP_BASE_CONNECTION (conn);
-    TpHandleRepoIface *handle_repo =
-        tp_base_connection_get_handles (base_conn, TP_HANDLE_TYPE_CONTACT);
-
     gpointer h = GUINT_TO_POINTER (handle);
     gboolean removed;
 
     removed = g_hash_table_remove (self->priv->pending_publish_requests, h);
     g_assert (removed);
-
-    tp_handle_unref (handle_repo, handle);
 }
 
 void
@@ -739,7 +725,7 @@ haze_contact_list_prep_remove_from_group (HazeContactList *self,
 
       if (default_group == group)
         {
-          g_set_error (error, TP_ERRORS, TP_ERROR_NOT_AVAILABLE,
+          g_set_error (error, TP_ERROR, TP_ERROR_NOT_AVAILABLE,
               "Contacts can't be removed from '%s' unless they are in "
               "another group", group->name);
           return FALSE;
@@ -1037,7 +1023,7 @@ haze_contact_list_set_contact_groups_async (TpBaseContactList *cl,
 
       for (i = 0; i < n_names; i++)
         {
-          if (tp_strdiff (group_name, names[i]))
+          if (!tp_strdiff (group_name, names[i]))
             {
               desired = TRUE;
               break;
